@@ -1,6 +1,8 @@
 from threading import Thread
 from watchdog.events import FileSystemEventHandler
 from watchdog.observers import Observer
+from multiprocessing.pool import ThreadPool
+import datetime
 import base64
 import logging
 import os
@@ -29,11 +31,14 @@ REDIS_TTL = int(os.getenv("REDIS_TTL", 60))
 REDIS_SAMPLE_RATE = int(os.getenv("REDIS_SAMPLE_RATE", 8)) # 1/8 images will be post to redis
 redis_hosts = requests.get(REDIS_HOST_LIST_URL).json() if REDIS_HOST_LIST_URL else [REDIS_HOST]
 
+WORKERS = int(os.getenv("WORKERS", 50))
 BASE64_ENCODE = "BASE64_ENCODE" in os.environ
 LOG_FILE = os.getenv("LOG_FILE", None)
 LOG_LEVEL = getattr(logging, os.getenv("LOG_LEVEL", "debug").upper())
 logger = logging.getLogger("broadcaster")
 
+pool = ThreadPool(processes=WORKERS)
+
 def log_on_error(func):
     def f(*args, **kwargs):
         try:
@@ -43,10 +48,20 @@ def log_on_error(func):
     return f
 
 class EventHandler(FileSystemEventHandler):
+    def __init__(self, *args, **kwargs):
+        super(EventHandler, self).__init__(*args, **kwargs)
+        self.last_event = datetime.datetime.now()
+
     def on_created(self, event):
+        self.last_event = datetime.datetime.now()
         if os.path.isdir(event.src_path):
             return
-        Thread(target=post, args=(event.src_path,)).start()
+        post_async(event.src_path)
+
+
+@log_on_error
+def post_async(path):
+    return pool.apply_async(func=post, args=(path,))
 
 
 @log_on_error
@@ -137,6 +152,10 @@ def run():
 
         while True:
             time.sleep(1)
+            now = datetime.datetime.now()
+            if now - event_handler.last_event > datetime.timedelta(minutes=1):
+                event_handler.last_event = now
+                logger.warning("No events received in the last minute.")
     except KeyboardInterrupt:
         logger.warning("Keyboard interruption. Shuting down.")
     except Exception as err:
